SWDEV-432490 - fix __HIP_NO_IMAGE_SUPPORT logic
1.Skip texture/image tests when __HIP_NO_IMAGE_SUPPORT is set to prevent inevitable silent failure
2.Simplify __HIP_NO_IMAGE_SUPPORT macros
Change-Id: I54ef12a239298c534a213edf39c05c2dad06a7f4
[ROCm/hip-tests commit: 0ee0e4ab4a]
This commit is contained in:
committed by
Rakesh Roy
parent
7df8798269
commit
14f6363879
@@ -46,7 +46,7 @@ texture<unsigned char, hipTextureType1D, hipReadModeNormalizedFloat> texuc;
|
||||
template<typename T>
|
||||
__global__ void normalizedValTextureTest(unsigned int numElements,
|
||||
float* pDst) {
|
||||
#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
|
||||
#if !__HIP_NO_IMAGE_SUPPORT
|
||||
unsigned int elementID = threadIdx.x;
|
||||
if (elementID >= numElements)
|
||||
return;
|
||||
@@ -149,6 +149,11 @@ static void runTest_hipTextureFilterMode() {
|
||||
TEST_CASE("Unit_hipNormalizedFloatValueTex_CheckModes") {
|
||||
CHECK_IMAGE_SUPPORT
|
||||
|
||||
#if __HIP_NO_IMAGE_SUPPORT
|
||||
HipTest::HIP_SKIP_TEST("__HIP_NO_IMAGE_SUPPORT is set");
|
||||
return;
|
||||
#endif
|
||||
|
||||
#if HT_AMD
|
||||
hipDeviceProp_t props;
|
||||
HIP_CHECK(hipGetDeviceProperties(&props, 0));
|
||||
|
||||
Reference in New Issue
Block a user